@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Duadua::Parser;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Browser::MicrosoftEdge
@@ -41,6 +41,7 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Bot::Msnbot
     Duadua::Parser::Bot::BotMisc
 
+    Duadua::Parser::Browser::GoogleApp
     Duadua::Parser::Browser::SamsungInternetBrowser
     Duadua::Parser::Browser::Yandex
     Duadua::Parser::Browser::DuckDuckGo
@@ -53,6 +54,8 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Bot::YahooJapanBot
     Duadua::Parser::Bot::HatenaBot
     Duadua::Parser::Bot::Feedly
+    Duadua::Parser::Bot::Reeder
+    Duadua::Parser::Bot::QuiteRSS
     Duadua::Parser::Bot::Feedbin
     Duadua::Parser::Bot::Inoreader
     Duadua::Parser::Bot::Fastladder
@@ -65,6 +68,7 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Bot::Netcraft
     Duadua::Parser::Bot::Barkrowler
     Duadua::Parser::Bot::SMTBot
+    Duadua::Parser::Bot::AdstxtCom
     Duadua::Parser::Bot::LetsEncrypt
 /;
 
@@ -211,7 +215,7 @@ __END__
 
 =head1 NAME
 
-Duadua - Detect User-Agent
+Duadua - Detect User-Agent, do up again!
 
 
 =head1 SYNOPSIS
@@ -325,7 +329,7 @@ The list of User Agent Parser
 
 =begin html
 
-<a href="https://github.com/bayashi/Duadua/blob/master/lib/Duadua.pm"><img src="https://img.shields.io/badge/Version-0.17-green?style=flat"></a> <a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png?style=flat"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/master/badge.svg?_t=1584976739"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1584976739&branch=master"/></a>
+<a href="https://github.com/bayashi/Duadua/blob/master/lib/Duadua.pm"><img src="https://img.shields.io/badge/Version-0.18-green?style=flat"></a> <a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png?style=flat"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/master/badge.svg?_t=1586321911"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1586321911&branch=master"/></a>
 
 =end html
 
