@@ -55,6 +55,29 @@ sub try {
             is_bot => 1,
         };
     }
+
+    if ( index($d->ua, ' Google-Site-Verification') > -1 ) {
+        my $h = {
+            name   => 'Google-Site-Verification',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m! Google-Site-Verification/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        return $h;
+    }
+
+    if ( index($d->ua, ' Google Page Speed Insights') > -1 ) {
+        my $h = {
+            name   => 'Google Page Speed Insights',
+            is_bot => 1,
+        };
+
+        return Duadua::Util->set_os($d, $h);
+    }
 }
 
 1;
